require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  describe Api::Dmo::HousingRequestInitializersController, :type => :api do
    routes { Hermes::Engine.routes }
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:admin) { create :administrator, auth_roles: ['superadministrateur'] }
    let!(:collab) { create(:user, auth_roles: ['collaborateur offre logement'])}
    let!(:demandeur) {create(:user)}
    let!(:other_user) {create(:user)}

    describe 'GET index' do
      let!(:hri1) do 
        create(
          :housing_request_initializer, 
          user: demandeur, 
          email: 'demandeur@mail.com',
          pin_code: "code",
          writers: [demandeur.id.to_s],
          hashed_pin_code: Digest::SHA2.new(512).hexdigest('code')
        )
      end 

      it 'as collab' do
        authenticated_header(request, collab)
        get 'index'
        expect(response).to have_http_status 200
        expect(json['data'].length).to eq 1
        expect(json['data'][0]['attributes']['pin_code']).to eq('code')
        expect(json['data'][0]['attributes']['email']).to eq('demandeur@mail.com')
      end

      it 'as creator' do 
        authenticated_header(request, demandeur)
        get 'index'
        expect(response).to have_http_status 200
        expect(json['data'].length).to eq 1
        expect(json['data'][0]['attributes']['pin_code']).to eq('unauthorized to see')
        expect(json['data'][0]['attributes']['email']).to eq('d*******r@mail.com')
      end 

      it 'as other user' do 
        authenticated_header(request, other_user)
        get 'index'
        expect(response).to have_http_status 200
        expect(json['data'].length).to eq 0
      end 

    end
  end
end