# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'


dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'integrationPJ.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::UpdatePJTask, type: :helper do
  let!(:xsd) {Nokogiri::XML::Schema(File.read(schema_path))}
  let!(:user1) {create(:user)}

 
  context 'with simple housing_offer' do
    let!(:applicant1) {
      create(
        :applicant,
        user: user1,
        monthly_charges: {},
        nationality: "1"
      )
    }
    
    let!(:housing_request1) do
      create(
        :housing_request,
        is_active: true,
        main_applicant: applicant1
      )
    end
    let!(:nud1) do
      create(
        :nud,
        housing_request: housing_request1,
        department: '12',
        creation_date: '2016-23-14T14:53:22',
        unique_number: "A1253EF84F3"
      )
    end
  end
  
  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end
  
  context 'with simple housing_request' do
    let!(:applicant1) {
      create(
        :applicant,
        user: user1,
        monthly_charges: {},
        nationality: "1"
      )
    }
  
    let!(:housing_request1) do
      create(
        :housing_request,
        is_active: true,
        main_applicant: applicant1
      )
    end
    let!(:nud1) do
      create(
        :nud,
        housing_request: housing_request1,
        department: '12',
        creation_date: '2016-23-14T14:53:22',
        unique_number: "A1253EF84F3"
      )
    end
    let!(:update_pj_task) do
      required_document = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      path = [Hermes::Engine.root, %w[spec xml_bouchon], "0_blob_bouchon"].flatten.join('/').to_s
      pn = Pathname.new(path)
      return {err: 'unknown file'} unless pn.exist?
      blob_bouchon = File.read(pn)
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      required_document.set_blobs([{filename: "superPad.pdf", blob: blob_bouchon}])
      required_document.sne_piece_id = "33290"
      required_document.save
      build(
        :update_pj_task,
        options: {housing_request_id: housing_request1.id,
                  num_unique: nud1.unique_number,
                  required_document_id: required_document.id}
      )
    end
    
    describe 'using to_xml' do
      it 'should return a valid xml' do
        expect(xsd.validate(Nokogiri::XML(update_pj_task.to_xml))).to eq([])
      end
    end
  end
end
